import test from 'ava';
import * as app from "./crypto.mjs";

const idSec = "a";
const mdp = "b";
//base58
const pubKey = "AoxVA41dGL2s4ogMNdbCw3FFYjFo5FPK36LuiW1tjGbG";
const secretKey = "3ZsmZhnRv137dS1s7Q3jFGKLTDyhkwguPHfnWBxzDCTTHKWGnYw9zBk3gcCUJCc72TEUuyzM7cqpo7c5LYhs1Qtv";
const seed = "9eADqX8V6VcPdJCHCVYiE1Vnift9nFNrvr9aTaXA5RJc";

test('b58 should decode/encode well', t => {
    t.is(app.b58.encode(app.b58.decode(pubKey)), pubKey);
});
test('saltPass2seed should convert salt & password to seed with scrypt', async t => {
    t.is(app.b58.encode(await app.saltPass2seed(idSec, mdp)), seed);
});
test('seed2keyPair should generate public and private key nacl/sodium way.', async t => {
    const rawSeed = app.b58.decode(seed);
    const rawKeyPair = app.seed2keyPair(rawSeed);
    t.is(app.b58.encode(rawKeyPair.publicKey), pubKey);
    t.is(app.b58.encode(rawKeyPair.secretKey), secretKey);
});
test('idSecPass2cleanKeys should output clean base58 keys and seed', async t => {
    const res = await app.idSecPass2cleanKeys(idSec, mdp);
    t.is(res.publicKey, pubKey);
    t.is(res.secretKey, secretKey);
    t.is(res.seed, seed);
    t.is(res.idSec, idSec);
    t.is(res.password, mdp);
});


